==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/pt/users.php <==
<?php
regGS("Reset search form", "");
regGS("That user name already exists, please choose a different login name.", "");
regGS("User may delete article attachments", "");
regGS("User may change article attachments", "");
regGS("User may add article attachments", "");
regGS("Staff management", "");
regGS("Subscriber management", "");
regGS("Account Name", "");
regGS("Full Name", "Nome Completo");
regGS("Delete user $1", "Eliminar utilizador $1");
regGS("User list is empty.", "");
regGS("You do not have the right to create user accounts.", "Não tem permissões para criar utilizadores");
regGS("Title", "Titulo");
regGS("Gender", "Sexo");
regGS("Mr.", "Sr");
regGS("Mrs.", "Sra");
regGS("Ms.", "Mn");
regGS("Dr.", "Dr(a)");
regGS("Male", "Masculino");
regGS("Female", "Feminino");
regGS("under 18", "Menos de 18 anos");
regGS("Age", "Idade");
regGS("Confirm password", "Confirme Palavra-passe");
regGS("E-Mail", "Endereço Electrónico");
regGS("City", "Cidade");
regGS("Street Address", "Morada");
regGS("Postal Code", "Podigo Postal");
regGS("State", "Distrito");
regGS("Phone", "Telefone");
regGS("Fax", "Telefax");
regGS("Contact Person", "Contacto Pessoal");
regGS("Second Phone", "Telefone 2");
regGS("Employer", "Empregado");
regGS("Employer Type", "Tipo de Empregado");
regGS("Corporate", "Empresa");
regGS("Non-Governmental Organisation", "Organizações Não Governamentais");
regGS("Government Agency", "Departamento Governamental");
regGS("Academic", "Acedémico");
regGS("Media", "");
regGS("Position", "Posição");
regGS("Show more user details", "");
regGS("Hide user details", "");
regGS("You must select a $1", "Tem de escolher um(a) $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "A Palavra-passe tem de ter pelos menos 6 caracteres e ambas as palavras-passe devem coincidir");
regGS("The user account could not be created.", "O Utilizador não pode ser criado");
regGS("User account $1 was created successfully.", "");
regGS("Click here to change password", "");
regGS("Old Password", "");
regGS("You do not have the right to change user account permissions.", "Não tem autorização para alterar permissões");
regGS("Permissions for $1 changed", "As Permissões de $1 foram alteradas");
regGS("You do not have the right to change user account information.", "Não tem permissão para alterar informações de Utilizador");
regGS("Click here to customize user permissions", "");
regGS("Click here to use existing user type permissions (discard customization)", "");
regGS("Click here to leave password unchanged", "");
regGS("User account information changed for $1", "Informações do Utilizador $1 foram alteradas");
regGS("The password you typed is incorrect.", "Palavra-passe incorrecta");
regGS("You do not have the right to delete user accounts.", "Não tem persmissões para eliminar Utilizadores");
regGS("Are you sure you want to delete the user account $1 ?", "Eliminar Utilizador $1?");
regGS("User account $1 was deleted successfully.", "");
regGS("User IP access list management", "Acesso por IP para o Utilizador");
regGS("No records.", "Sem registos");
regGS("Start IP", "IP Inicial");
regGS("Number of addresses", "Nº de Endereços");
regGS("The IP Group $1 has been created.", "O Grupo de IP's $1 foi criado");
regGS("There was an error creating the IP address group.", "");
regGS("Are you sure you want to delete the IP Group $1?", "Eliminar Grupo de IP's $1?");
regGS("The IP address group $1 has been deleted.", "Grupo de IP's $1 foi eliminado");
regGS("User '$1' information was changed successfully.", "");
regGS("IP address", "");
regGS("fill in from left to right at least one input box", "");
regGS("User Type", "");
regGS("You must input a valid EMail address.", "");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "");
regGS("Delete subscriptions to $1", "");
regGS("Change user account information", "Alterar informações de Utilizador");
regGS("The IP address group $1:$2 conflicts with another existing group.", "");
regGS("Creation Date", "");
regGS("User management", "Gestão de Utilizadores");
regGS("Set", "Escolher");
regGS("Update", "Actualizar");
regGS("Rights", "Permissões");
regGS("IP Access", "Acesso por IP");
regGS("User Name", "Nome de Utilizador");
regGS("Staff", "Staff");
regGS("Adding new user account", "Adicionando novo utilizador");
regGS("You must select an user type.", "Tem de escolher um tipo de Utilizador");
regGS("The user account $1 has been created.", "O Utilizador $1 foi criado");
regGS("Please check if an account with the same user name does not already exist.", "Verifique se já não existe um utilizador com o mesmo nome.");
regGS("Change password", "Alterar Palavra-Passe");
regGS("You do not have the right to change user passwords.", "Não tem permissões para alterar Palavras-Passe");
regGS("Changing user password", "Alterando Palavra-Passe");
regGS("The password could not be changed.", "A Palavra-Passe não pode ser alterada");
regGS("The password has been changed.", "A Palavra-Passe Não pode ser alterada");
regGS("User may manage templates", "Permissão para gerir Modelos");
regGS("User may add/change country entries", "Permissão para Adicionar/Alterar entradas de Paises");
regGS("Edit user account permissions", "Alterar Permissões");
regGS("This user account does not have permissions information.", "Este Utilizador não tem permissões");
regGS("Updating user account permissions", "Actualizando permissões de Utilizador");
regGS("User account permissions have been successfuly updated.", "As permissões foram alteradas");
regGS("User account permissions could not be updated.", "As permissões não podem ser alteradas");
regGS("Changing user account information", "Alterando informações de Utilizador");
regGS("User account information has been changed.", "Informação de Utilizador foram alteradas");
regGS("User account information could not be changed.", "Informações do Utilizador não podem ser alteradas");
regGS("Old password", "Palavra-passe Actual");
regGS("New password", "Nova Palavra-passe");
regGS("Confirm new password", "Confirme a nova Palavra-passe");
regGS("Changing your password", "Alterando Palavra-passe");
regGS("User $1 changed his password", "Utilizador $1 alterou a sua Palavra-passe");
regGS("Delete user account", "Eliminar Utilizador");
regGS("Deleting user account", "Eliminar Utilizadores");
regGS("The user account $1 could not be deleted.", "Utilizador $1 não pode ser eliminado");
regGS("No such user.", "Utilizador desconhecido");
regGS("Delete IP Group $1", "Apagar Grupo de IP $1");
regGS("IP Access List", "Lista de Acesso por IP");
regGS("Adding new IP Group", "Adicionando Grupo de IP's");
regGS("The IP Group could not be created.", "O Grupo de IP's não pode ser criado");
regGS("Please check if an account with the same IP Group does not already exist.", "Verifique se já não existe um utilizador com o mesmo Grupo de IP's");
regGS("Delete IP Group", "Eliminar Grupo de IP's");
regGS("You do not have the right to delete IP Groups.", "Não tem permissões para eliminar Grupos de IP's");
regGS("No such IP Group.", "Não existe o Grupo de IP's");
regGS("Deleting IP Group", "Eliminando Grupo de IP's");
regGS("The IP Group could not be deleted.", "Grupo de IP's não pode ser eliminado");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/pt/users.php <==
<?php
regGS("65 or over", "65 ou mais");
regGS("User may translate articles", "Permissão para traduzir artigos");
regGS("User may move articles", "Permissão para mover artigos");
regGS("User may find and replace", "Permissão para Procurar e Substituir");
regGS("User may change system preferences", "Permissão para alterar definições do sistema");
regGS("User may attach topics to articles", "Permissão para adicionar temas a artigos");
regGS("User may attach images to articles", "Permissão para adicionar imagens a artigos");
regGS("User may add special characters", "Permissão para usar caracteres especiais");
regGS("Reset search form", "Limpar opções de procura");
regGS("That user name already exists, please choose a different login name.", "Nome já existente, por favor escoha um diferente.");
regGS("User may delete article attachments", "Permissão para eliminar anexos de artigos");
regGS("User may change article attachments", "Permissão para alterar anexos de artigos");
regGS("User may add article attachments", "Permissão para adicionar anexos a artigos");
regGS("Staff management", "Manutenção de Pessoal Editorial");
regGS("Subscriber management", "Manutenção de Assinantes");
regGS("Account Name", "Nome de Conta");
regGS("Full Name", "Nome Completo");
regGS("Delete user $1", "Eliminar utilizador $1");
regGS("User list is empty.", "A Lista de Utilizadores esta vazia");
regGS("You do not have the right to create user accounts.", "Não tem permissões para criar utilizadores");
regGS("Title", "Titulo");
regGS("Gender", "Sexo");
regGS("Mr.", "Sr");
regGS("Mrs.", "Sra");
regGS("Ms.", "Mn");
regGS("Dr.", "Dr(a)");
regGS("Male", "Masculino");
regGS("Female", "Feminino");
regGS("under 18", "Menos de 18 anos");
regGS("Age", "Idade");
regGS("Confirm password", "Confirme Palavra-passe");
regGS("E-Mail", "Endereço Electrónico");
regGS("City", "Cidade");
regGS("Street Address", "Morada");
regGS("Postal Code", "Podigo Postal");
regGS("State", "Distrito");
regGS("Phone", "Telefone");
regGS("Fax", "Telefax");
regGS("Contact Person", "Contacto Pessoal");
regGS("Second Phone", "Telefone 2");
regGS("Employer", "Empregado");
regGS("Employer Type", "Tipo de Empregado");
regGS("Corporate", "Empresa");
regGS("Non-Governmental Organisation", "Organizações Não Governamentais");
regGS("Government Agency", "Departamento Governamental");
regGS("Academic", "Acedémico");
regGS("Media", "");
regGS("Position", "Posição");
regGS("Show more user details", "Mostrar Detalhes");
regGS("Hide user details", "Esconder Detalhes");
regGS("You must select a $1", "Tem de escolher um(a) $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "A Palavra-passe tem de ter pelos menos 6 caracteres e ambas as palavras-passe devem coincidir");
regGS("The user account could not be created.", "O Utilizador não pode ser criado");
regGS("User account $1 was created successfully.", "Utilizador $1 criado com sucesso.");
regGS("Click here to change password", "Carregue para alterar a Palavra-Passe");
regGS("Old Password", "Palavra-Passe anterior");
regGS("You do not have the right to change user account permissions.", "Não tem autorização para alterar permissões");
regGS("Permissions for $1 changed", "As Permissões de $1 foram alteradas");
regGS("You do not have the right to change user account information.", "Não tem permissão para alterar informações de Utilizador");
regGS("Click here to customize user permissions", "Carregue para custimizar as permissões de utilizador");
regGS("Click here to use existing user type permissions (discard customization)", "Carregue para usar as permissões de um utilizador ja existente (eliminará a customização)");
regGS("Click here to leave password unchanged", "Carregue para deixar a Palavra-Passe inalterada");
regGS("User account information changed for $1", "Informações do Utilizador $1 foram alteradas");
regGS("The password you typed is incorrect.", "Palavra-passe incorrecta");
regGS("You do not have the right to delete user accounts.", "Não tem persmissões para eliminar Utilizadores");
regGS("Are you sure you want to delete the user account $1 ?", "Eliminar Utilizador $1?");
regGS("User account $1 was deleted successfully.", "Utilizador $1 foi eliminado");
regGS("User IP access list management", "Acesso por IP para o Utilizador");
regGS("No records.", "Sem registos");
regGS("Start IP", "IP Inicial");
regGS("Number of addresses", "Nº de Endereços");
regGS("The IP Group $1 has been created.", "O Grupo de IP's $1 foi criado");
regGS("There was an error creating the IP address group.", "Ocorreu um erro na criação do Grupo de IP's");
regGS("Are you sure you want to delete the IP Group $1?", "Eliminar Grupo de IP's $1?");
regGS("The IP address group $1 has been deleted.", "Grupo de IP's $1 foi eliminado");
regGS("User '$1' information was changed successfully.", "Informações do Utilizador $1 alteradas.");
regGS("IP address", "Endereço IP");
regGS("fill in from left to right at least one input box", "Preencha da esquerda para a direita e pelo menos um valor");
regGS("User Type", "Tipo de Utilizador");
regGS("You must input a valid EMail address.", "Tem de especificar um endereço electrónico válido.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "A Palavra-Passe e a sua confirmação têm de ter um comprimento minimo de 6 caracteres e serem coincidentes.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "Tem de usar um numero entre 0 e 255 para o $1º campo de IP de inicio.");
regGS("Delete subscriptions to $1", "Anular assinatura para $1");
regGS("Change user account information", "Alterar informações de Utilizador");
regGS("The IP address group $1:$2 conflicts with another existing group.", "Existe um conflito entre o Grupo de IP's $1:$2 com um já existente.");
regGS("Creation Date", "Data de criação");
regGS("User management", "Gestão de Utilizadores");
regGS("Set", "Escolher");
regGS("Update", "Actualizar");
regGS("Rights", "Permissões");
regGS("IP Access", "Acesso por IP");
regGS("User Name", "Nome de Utilizador");
regGS("Staff", "Staff");
regGS("Adding new user account", "Adicionando novo utilizador");
regGS("You must select an user type.", "Tem de escolher um tipo de Utilizador");
regGS("The user account $1 has been created.", "O Utilizador $1 foi criado");
regGS("Please check if an account with the same user name does not already exist.", "Verifique se já não existe um utilizador com o mesmo nome.");
regGS("Change password", "Alterar Palavra-Passe");
regGS("You do not have the right to change user passwords.", "Não tem permissões para alterar Palavras-Passe");
regGS("Changing user password", "Alterando Palavra-Passe");
regGS("The password could not be changed.", "A Palavra-Passe não pode ser alterada");
regGS("The password has been changed.", "A Palavra-Passe Não pode ser alterada");
regGS("User may manage templates", "Permissão para gerir Modelos");
regGS("User may add/change country entries", "Permissão para Adicionar/Alterar entradas de Paises");
regGS("Edit user account permissions", "Alterar Permissões");
regGS("This user account does not have permissions information.", "Este Utilizador não tem permissões");
regGS("Updating user account permissions", "Actualizando permissões de Utilizador");
regGS("User account permissions have been successfuly updated.", "As permissões foram alteradas");
regGS("User account permissions could not be updated.", "As permissões não podem ser alteradas");
regGS("Changing user account information", "Alterando informações de Utilizador");
regGS("User account information has been changed.", "Informação de Utilizador foram alteradas");
regGS("User account information could not be changed.", "Informações do Utilizador não podem ser alteradas");
regGS("Old password", "Palavra-passe Actual");
regGS("New password", "Nova Palavra-passe");
regGS("Confirm new password", "Confirme a nova Palavra-passe");
regGS("Changing your password", "Alterando Palavra-passe");
regGS("User $1 changed his password", "Utilizador $1 alterou a sua Palavra-passe");
regGS("Delete user account", "Eliminar Utilizador");
regGS("Deleting user account", "Eliminar Utilizadores");
regGS("The user account $1 could not be deleted.", "Utilizador $1 não pode ser eliminado");
regGS("No such user.", "Utilizador desconhecido");
regGS("Delete IP Group $1", "Apagar Grupo de IP $1");
regGS("IP Access List", "Lista de Acesso por IP");
regGS("Adding new IP Group", "Adicionando Grupo de IP's");
regGS("The IP Group could not be created.", "O Grupo de IP's não pode ser criado");
regGS("Please check if an account with the same IP Group does not already exist.", "Verifique se já não existe um utilizador com o mesmo Grupo de IP's");
regGS("Delete IP Group", "Eliminar Grupo de IP's");
regGS("You do not have the right to delete IP Groups.", "Não tem permissões para eliminar Grupos de IP's");
regGS("No such IP Group.", "Não existe o Grupo de IP's");
regGS("Deleting IP Group", "Eliminando Grupo de IP's");
regGS("The IP Group could not be deleted.", "Grupo de IP's não pode ser eliminado");
?>
